/* global require, describe, it, assert, beforeEach */

var assert = require('assert');
var [% module %] = require('[% module %]');

describe('load', function() {
    it('works', function() {
        assert.equal(1,1);
    });
});
