[%- UNLESS method %][% method = 'post'   %][% END -%]
[%- UNLESS action %][% action = '#'      %][% END -%]
[%- UNLESS legend %][% legend = 'legend' %][% END -%]
<form method="[% method %]" action="[% action %]">

	<fieldset>
		<legend>[% legend %]</legend>
		<div>
			<label for="input-name">label</label>
			<input type="text" name="input-name" id="input-name" value="text"/>
		</div>
	</fieldset>

	<fieldset>
		<div>
			<input type="submit" value="Submit"/>
		</div>
	</fieldset>

</form>
