[% UNLESS title %][% title = 'Untitled Document' %][% END -%]
<!DOCTYPE html
	PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
	 "http://www.w3.org/TR/xhtml1/DTD/html4.01-transitional.dtd">
<html>
	<head>
		<title>[% title %]</title>
		<meta http-equiv="Content-Type"     content="text/html; charset=utf-8">
		<meta http-equiv="Content-Language" content="en-au">
		<meta name="ROBOTS"      content="INDEX,FOLLOW"/>
		<meta name="author"      content="[% contact.fullname %]">
		<meta name="copyright"   content="Copyright (c) [% year %] [% contact.fullname %], All Rights Reserved">
		<meta name="description" content="">
		<meta name="keywords"    content="">
		<link href="/css/styles.css" rel="stylesheet" type="text/css" media="screen, print" />
		<style type="text/css">
		<!--/* <![CDATA[ */

		/* ]]> */-->
		</style>
		<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.8.2/jquery.min.js"></script>
		<script type="text/javascript" src="/js/code.js"></script>
		<script type="text/javascript">
		<!--/* <![CDATA[ */

		/* ]]> */-->
		</script>
	</head>
	<body>


	</body>
</html>
